function maxk = template_indtestpowermaxk(x, numLevels, ord, j1, j2, j3, alpha, beta, TestParam, PowerParam)
%TEMPLATE_INDTESTPOWERMAXK Template maximal conditioning set cardinality with sufficient conditional independence test power estimator function (optimized)
%
%  WARNING - Future versions of the toolbox may require you to update
%  custom functions.
%
%  Directions for Customizing
%
%    1. Make a copy of this function with a new name
%    2. Edit your new function according to the code comments marked ***
%    3. Type HELP ORG.MENSXMACHINA.PGM.INDTESTPOWERMAXK to see a list of 
%       other maximal conditioning set cardinality with sufficient
%       conditional independence test power estimator functions.
%
%   MAXK = TEMPLATE_INDTESTPOWERMAXK(X, NUMLEVELS, ORD, J1, J2, J3, ALPHA, BETA, TESTPARAM, POWERPARAM)
%   returns an upper bound MAXK on the maximal cardinality of a subset J4
%   of column(s) J3 of matrix X such that the power of the test of
%   conditional independence of the null hypothesis that column J1 of X is
%   independent of column J2 given column(s) J4, performed at the
%   (ALPHA*100)% significance level, is estimated to be >= 1 - BETA. X is a
%   matrix of observations without any missing (NaN) values. NUMLEVELS is a
%   numeric vector of length equal to the number of columns of X,
%   containing their number of levels where the columns of X contain
%   categorical data in numeric form (i.e. value i corresponds to the i-th
%   level) and NaN where they contain truly numeric data. ORD is a logical
%   vector of length equal to the number of columns of X, containing
%   logical 1 (true) where the columns of X contain ordinal categorical 
%   data in numeric form and logical 0 (false) otherwise. J1 and J2 are
%   positive integers and J3 is a positive integer, a vector of positive
%   integers or an empty numeric array ([]). ALPHA and BETA are scalars
%   from 0 to 1. TESTPARAM is a structure of test parameters that is also
%   passed to the p-value and power estimation functions. POWERPARAM is a 
%   structure of power estimation parameters also passed to the power
%   estimator function.

%   Copyright 2010-2011 Mens X Machina
%
%   This file is part of Mens X Machina Commons Toolbox.
%
%   Mens X Machina Commons Toolbox is free software: you can redistribute
%   it and/or modify it under the terms of the GNU General Public License 
%   as published by the Free Software Foundation, either version 3 of the
%   License, or (at your option) any later version.
%
%   Mens X Machina Commons Toolbox is distributed in the hope that it will
%   be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
%   of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
%   General Public License for more details.
%
%   You should have received a copy of the GNU General Public License
%   along with Mens X Machina Commons Toolbox. If not, see
%   <http://www.gnu.org/licenses/>.

% *** CUSTOMIZE HERE
% *** return the maximal conditioning set cardinality with sufficient
% *** conditional independence test power
maxk = length(j3);

end