function [p stat] = chi2indtestpopt(x, numLevels, ~, j2, j, j3, TestParam, PowerTestParam, ~)
%CHI2INDTESTPOPT p-value of Chi-square conditional independence test (optimized)
%   P = CHI2INDTESTPOPT(X, NUMLEVELS, ORD, J1, J2, J3, TESTPARAM, POWERTESTPARAM, PARAM)
%   returns the p-value P of the Chi-square test of conditional 
%   independence performed by 
%   ORG.MENSXMACHINA.COMMONS.STATS.CHI2INDTESTOPT(X, NUMLEVELS, J1, J2, J3, CHIINDTESTPARAM)
%   with CHIINDTESTPARAM = 
%   struct('Alpha', NaN, 'Stat', TESTPARAM.Stat, 'Obs', OBS, 'DoF', DOF),
%   where OBS and DOF are POWERTESTPARAM.Obs and POWERTESTPARAM.DoF if they
%   exist, [] otherwise. ORD and PARAM are not used.
%
%   CHI2INDTESTPOPT is used as PFUN in constraint-based learning functions
%   in conjunction with
%   ORG.MENSXMACHINA.PGM.INDTESTPOWER.CHI2INDTESTHSPOPT as POWERFUN and 
%   ORG.MENSXMACHINA.PGM.INDTESTPOWERMAXK.CHI2INDTESTHSPMAXKOPT as
%   POWERMAXKFUN.
%
%   [P, STAT] = CHI2INDTESTPOPT(X, NUMLEVELS, ORD, J1, J2, J3, TESTPARAM, POWERTESTPARAM, PARAM)
%   also returns the test statistic STAT.
%
%   See also ORG.MENSXMACHINA.PGM.INDTESTPOWER.CHI2INDTESTHSPOPT,
%   ORG.MENSXMACHINA.PGM.INDTESTPOWERMAXK.CHI2INDTESTHSPMAXKOPT

%   Copyright 2010-2011 Mens X Machina
%
%   This file is part of Mens X Machina Probabilistic Graphical Model
%   Toolbox.
%
%   Mens X Machina Probabilistic Graphical Model Toolbox is free software:
%   you can redistribute it and/or modify it under the terms of the GNU 
%   General Public License as published by the Free Software Foundation,
%   either version 3 of the License, or (at your option) any later version.
%
%   Mens X Machina Probabilistic Graphical Model Toolbox is distributed in
%   the hope that it will be useful, but WITHOUT ANY WARRANTY; without even
%   the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
%   PURPOSE. See the GNU General Public License for more details.
%
%   You should have received a copy of the GNU General Public License along
%   with Mens X Machina Probabilistic Graphical Model Toolbox. If not, see
%   <http://www.gnu.org/licenses/>.

persistent ChiIndTestParam;

import org.mensxmachina.commons.stats.*;

if isempty(ChiIndTestParam)
    ChiIndTestParam = struct('Alpha', NaN, 'Stat', [], 'Obs', [], 'DoF', []);
end

% update stat, leave alpha NaN
ChiIndTestParam.Stat = TestParam.Stat;

if isfield(PowerTestParam, 'Obs')
    ChiIndTestParam.Obs = PowerTestParam.Obs;
else
    ChiIndTestParam.Obs = [];
end

if isfield(PowerTestParam, 'DoF')
    ChiIndTestParam.DoF = PowerTestParam.DoF;
else
    ChiIndTestParam.DoF = [];
end

[~, p, stat] = chi2indtestopt(x, numLevels, j2, j, j3, ChiIndTestParam);

end