function [p stat] = fisherzindtestpopt(x, ~, ~, j1, j2, j3, ~, ~, ~)
%FISHERZINDTESTPOPT p-value of Fisher's Z test of conditional independence (optimized)
%   P = FISHERZINDTESTOPT(X, NUMLEVELS, ORD, J1, J2, J3, TESTPARAM, POWERTESTPARAM, PARAM)
%   returns the p-value P of the Fisher's Z test of conditional 
%   independence performed by 
%   ORG.MENSXMACHINA.COMMONS.STATS.FISHERZTESTOPT(X, J1, J2, J3, FISHERZINDTESTPARAM)
%   with FISHERZINDTESTPARAM = struct('Alpha', NaN). NUMLEVELS, ORD, 
%   TESTPARAM, POWERTESTPARAM and PARAM are not used.
%
%   FISHERZINDTESTOPT is used as PFUN in constraint-based learning
%   functions in conjunction with
%   ORG.MENSXMACHINA.PGM.INDTESTPOWER.CHI2INDTESTHSPOPT as POWERFUN and
%   ORG.MENSXMACHINA.PGM.INDTESTPOWERMAXK.CHI2INDTESTHSPMAXKOPT as
%   POWERMAXKFUN.
%
%   [P, ZSTAT] = FISHERZINDTESTOPT(X, NUMLEVELS, ORD, J1, J2, J3, TESTPARAM, POWERTESTPARAM, PARAM)
%   also returns the Fisher's Z statistic ZSTAT.
%
%   See also ORG.MENSXMACHINA.PGM.INDTESTPOWER.CHI2INDTESTHSPOPT,
%   ORG.MENSXMACHINA.PGM.INDTESTPOWERMAXK.CHI2INDTESTHSPMAXKOPT

%   Copyright 2010-2011 Mens X Machina
%
%   This file is part of Mens X Machina Probabilistic Graphical Model
%   Toolbox.
%
%   Mens X Machina Probabilistic Graphical Model Toolbox is free software:
%   you can redistribute it and/or modify it under the terms of the GNU 
%   General Public License as published by the Free Software Foundation,
%   either version 3 of the License, or (at your option) any later version.
%
%   Mens X Machina Probabilistic Graphical Model Toolbox is distributed in
%   the hope that it will be useful, but WITHOUT ANY WARRANTY; without even
%   the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
%   PURPOSE. See the GNU General Public License for more details.
%
%   You should have received a copy of the GNU General Public License along
%   with Mens X Machina Probabilistic Graphical Model Toolbox. If not, see
%   <http://www.gnu.org/licenses/>.

persistent FisherZIndTestParam;

import org.mensxmachina.commons.stats.*;

if isempty(FisherZIndTestParam)
    FisherZIndTestParam = struct('Alpha', NaN);
end

[~, p, stat] = fisherzindtestopt(x, j1, j2, j3, FisherZIndTestParam);

end