function [power PowerPParam] = indtestpwropt(x, numLevels, ~, j1, j2, j3, ~, ~, PowerParam)
%INDTESTPWROPT Estimated power of generic conditional independence test (optimized)
%   POWER = INDTESTPWROPT(X, NUMLEVELS, ORD, J1, J2, J3, ALPHA, TESTPARAM, POWERPARAM)
%   returns an estimate POWER of the power of the generic test of
%   conditional independence performed by 
%   ORG.MENSXMACHINA.COMMONS.STATS.INDTESTOPT(X, NUMLEVELS, J1, J2, J3, CHI2INDTESTPARAM, FISHERZINDTESTPARAM)
%   with CHI2INDTESTPARAM = 
%   struct('Alpha', ALPHA, 'Stat', STAT, 'Obs', OBS, 'DoF', DOF) for any
%   STAT, OBS, DOF and FISHERZINDTESTPARAM = struct('Alpha', ALPHA). POWER
%   is computed by CHI2INDTESTHPSOPT(X, NUMLEVELS, [], J1, J2, J3, [], [], [], CHI2INDTESTHPSPARAM), 
%   where CHI2INDTESTHPSPARAM = 
%   struct('Hps', POWERPARAM.Chi2IndTestHspParam.Hps), when J1, J2 and J3
%   all specify columns of matrix X that contain categorical data in
%   numeric form and is 1 otherwise.
%
%   INDTESTPWROPT is used as POWERFUN in constraint-based learning
%   functions in conjunction with
%   ORG.MENSXMACHINA.PGM.INDTESTP.INDTESTPOPT as PFUN and 
%   ORG.MENSXMACHINA.PGM.INDTESTPOWERMAXK.INDTESTPWRMAXKOPT as
%   POWERMAXKFUN.
%
%   [POWER, POWERPPARAM] = INDTESTPWROPT(X, NUMLEVELS, ORD, J1, J2, J3, ALPHA, BETA, TESTPARAM, POWERPARAM)
%   also returns POWERPPARAM returned by 
%   CHI2INDTESTHPSOPT(X, NUMLEVELS, [], J1, J2, J3, [], [], [], CHI2INDTESTHPSPARAM)
%   when J1, J2 and J3 all specify columns of X that contain categorical
%   data in numeric form and an empty structure otherwise.
%
%   See also ORG.MENSXMACHINA.PGM.INDTESTP.INDTESTPOPT, 
%   ORG.MENSXMACHINA.PGM.INDTESTPOWERMAXK.INDTESTPWRMAXKOPT  

%   Copyright 2010-2011 Mens X Machina
%
%   This file is part of Mens X Machina Probabilistic Graphical Model
%   Toolbox.
%
%   Mens X Machina Probabilistic Graphical Model Toolbox is free software:
%   you can redistribute it and/or modify it under the terms of the GNU 
%   General Public License as published by the Free Software Foundation,
%   either version 3 of the License, or (at your option) any later version.
%
%   Mens X Machina Probabilistic Graphical Model Toolbox is distributed in
%   the hope that it will be useful, but WITHOUT ANY WARRANTY; without even
%   the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
%   PURPOSE. See the GNU General Public License for more details.
%
%   You should have received a copy of the GNU General Public License along
%   with Mens X Machina Probabilistic Graphical Model Toolbox. If not, see
%   <http://www.gnu.org/licenses/>.

persistent Chi2IndTestHspParam;

if isempty(Chi2IndTestHspParam)
    Chi2IndTestHspParam = struct('Hps', NaN);
end

% update HPS
Chi2IndTestHspParam.Hps = PowerParam.Chi2IndTestHspParam.Hps;

if all(~isnan(numLevels)) 
    
    % we have the NumLevels vector anyway, so it is faster to use it to find
    % the categorical variables than call
    % all(datasetfun(@(var) isa(var, 'categorical'), a))

    % all variables are categorical
    [power PowerPParam] = chi2indtesthspopt(x, numLevels, [], j1, j2, j3, [], [], [], Chi2IndTestHspParam);
    
else
    
    % some variables are numeric
    
    % always return 1
    power = 1;
    PowerPParam = struct();

end

end