function maxk = chi2indtesthspmaxkopt(x, numLevels, ~, j1, j2, j3, ~, ~, ~, PowerParam)
%CHI2INDTESTHSPMAXKOPT Maximal cardinality of a conditioning set with sufficient heuristic size power for chi-square test of conditional independence (optimized)
%   MAXK = CHI2INDTESTHSPMAXKOPT(X, NUMLEVELS, ORD, J1, J2, J3, ALPHA, BETA, TESTPARAM, POWERPARAM)
%   returns an upper bound MAXK on the maximal cardinality of a subset J4
%   of J3 such that POWER = CHI2INDTESTHSPOPT(X, NUMLEVELS, ORD, J1, J2, J4, ALPHA, TESTPARAM, POWERPARAM)
%   returns a power estimate POWER >= 1 - BETA.
%
%   CHI2INDTESTHSPMAXKOPT is used as POWERMAXKFUN in constraint-based
%   learning functions in conjunction with
%   ORG.MENSXMACHINA.PGM.INDTESTP.CHI2INDTESTPOPT as PFUN and 
%   ORG.MENSXMACHINA.PGM.INDTESTPOWER.CHI2INDTESTHSPOPT as POWERFUN.
%
%   See also ORG.MENSXMACHINA.PGM.INDTESTP.CHI2INDTESTPOPT, 
%   ORG.MENSXMACHINA.PGM.INDTESTPOWER.CHI2INDTESTHSPOPT

%   Copyright 2010-2011 Mens X Machina
%
%   This file is part of Mens X Machina Probabilistic Graphical Model
%   Toolbox.
%
%   Mens X Machina Probabilistic Graphical Model Toolbox is free software:
%   you can redistribute it and/or modify it under the terms of the GNU 
%   General Public License as published by the Free Software Foundation,
%   either version 3 of the License, or (at your option) any later version.
%
%   Mens X Machina Probabilistic Graphical Model Toolbox is distributed in
%   the hope that it will be useful, but WITHOUT ANY WARRANTY; without even
%   the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
%   PURPOSE. See the GNU General Public License for more details.
%
%   You should have received a copy of the GNU General Public License along
%   with Mens X Machina Probabilistic Graphical Model Toolbox. If not, see
%   <http://www.gnu.org/licenses/>.

import org.mensxmachina.commons.stats.*;

if isempty(j3)
    maxk = 0;
    return;
end

% get # of observations
nobs = size(x, 1);

% conservative estimate of MAXK
% derived from nobs/(numLevels(j1)*numLevels(j2)*min(numLevels(j3))^maxk) >= hps
maxk = round(log(nobs/(PowerParam.Hps*numLevels(j1)*numLevels(j2)))/log(min(numLevels(j3))));

% limit maxk to [0, length(j3)]
maxk = max(min(maxk, length(j3)), 0);

end