function bnetsamplesave
%BNETSAMPLESAVE Save sample package samples

%   Copyright 2010-2011 Mens X Machina
%
%   This file is part of Mens X Machina Probabilistic Graphical Model
%   Toolbox.
%
%   Mens X Machina Probabilistic Graphical Model Toolbox is free software:
%   you can redistribute it and/or modify it under the terms of the GNU 
%   General Public License as published by the Free Software Foundation,
%   either version 3 of the License, or (at your option) any later version.
%
%   Mens X Machina Probabilistic Graphical Model Toolbox is distributed in
%   the hope that it will be useful, but WITHOUT ANY WARRANTY; without even
%   the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
%   PURPOSE. See the GNU General Public License for more details.
%
%   You should have received a copy of the GNU General Public License along
%   with Mens X Machina Probabilistic Graphical Model Toolbox. If not, see
%   <http://www.gnu.org/licenses/>.

bnetds = dataset( ...
	{{'bif'; 'xdsl'; 'xdsl'; 'xdsl'; 'xdsl'; 'bif'; 'xdsl'}, 'format'}, ...
    {{'alarm.bif'; 'andes.xdsl'; 'barley.xdsl'; 'hailfinder.xdsl'; 'Hepar II.xdsl'; 'insurance.bif'; 'win95pts.xdsl'}, 'fileName'}, ...
    'ObsNames', {'alarm', 'andes', 'barley', 'hailfinder', 'heparii', 'insurance', 'win95pts'} ...
    );

nSamplings = 100; % number of samplings of each net
sampleSize = 5000;

bnetNames = get(bnetds, 'ObsNames');

parfor i=1:length(bnetNames) % for each net
    
    % load net
    S = load( sprintf('mxm_pgm_%s_bnet', bnetNames{i}));
    
	% reset default random number stream
    reset(RandStream.getDefaultStream);     

    %fprintf('%d: %s\n', i, num2str(randperm(10)));
    
    for j=1:nSamplings % for each sampling
        bnetsamplesave_single(S.bnet, bnetNames{i}, j, sampleSize);
    end
    
end

end

function bnetsamplesave_single(bnet, bnetName, j, sampleSize)
        
sampleFile = sprintf('mxm_pgm_%s_sample_%d.mat', bnetName, j);

%{
if exist(sampleFile, 'file')
    disp('skip');
    return;
end
%}

%fprintf('\nPerforming %d-th sampling of %s with sample size %d.\n', j, bnetName, sampleSize );

% get a random sample of this size from the network
a = bnet.randomds(sampleSize);

% save sample
save(sampleFile, 'a');

%{
% debug: check for constant columns
load(sampleFile, 'a');

a_d = removeconstantrows(double(a)')';

if ~isequal(size(a_d), size(a))
    bnetName
end
%}

end