function bnetsave
%BNETSAVE Save Bayesian Network objects accompanying this toolbox

%   Copyright 2010-2011 Mens X Machina
%
%   This file is part of Mens X Machina Probabilistic Graphical Model
%   Toolbox.
%
%   Mens X Machina Probabilistic Graphical Model Toolbox is free software:
%   you can redistribute it and/or modify it under the terms of the GNU 
%   General Public License as published by the Free Software Foundation,
%   either version 3 of the License, or (at your option) any later version.
%
%   Mens X Machina Probabilistic Graphical Model Toolbox is distributed in
%   the hope that it will be useful, but WITHOUT ANY WARRANTY; without even
%   the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
%   PURPOSE. See the GNU General Public License for more details.
%
%   You should have received a copy of the GNU General Public License along
%   with Mens X Machina Probabilistic Graphical Model Toolbox. If not, see
%   <http://www.gnu.org/licenses/>.

% download XDSL files from http://genie.sis.pitt.edu/networks.html
% download BIF files from http://www.cs.huji.ac.il/~galel/Repository/

bnetds = dataset( ...
	{{'bif'; 'xdsl'; 'xdsl'; 'xdsl'; 'xdsl'; 'bif'; 'xdsl'}, 'format'}, ...
    {{'alarm.bif'; 'andes.xdsl'; 'barley.xdsl'; 'hailfinder.xdsl'; 'Hepar II.xdsl'; 'insurance.bif'; 'win95pts.xdsl'}, 'fileName'}, ...
    'ObsNames', {'alarm', 'andes', 'barley', 'hailfinder', 'heparii', 'insurance', 'win95pts'} ...
    );

bnetNames = bnetds.Properties.ObsNames;

for i=1:size(bnetds, 1) % for each net
        
    bnetFile = sprintf('mxm_pgm_%s_bnet.mat', lower(bnetNames{i}));
    
    % debug
    %{
    bnetNames{i}
    load(bnetFile, 'bnet');
    
    if exist('bnet', 'var')
        for j=1:bnet.NumNodes
            if ~isempty(find(bnet.Param{j} == 1, 1))
                disp('yes');
                %bnet.VarNames{j}
                break;
            end
        end
    end
    continue;
    %}
    
    if strcmp(bnetds{i, 'format'}, 'bif')
    
        fprintf('\nReading %s network''s BIF file.\n', bnetNames{i});
        bnet = org.mensxmachina.pgm.bifread(bnetds.fileName{i}, 'nominal');
    %{
    elseif strcmp(bnetds{i, 'format'}, 'dsl')
    
        fprintf('\nReading %s network''s DSL file.\n', bnetNames{i});
        load(bnetds.fileName{i});
        bnet = org.mensxmachina.pgm.dsl2pgm(nodes);
    %}
    else
    
        fprintf('\nReading %s network''s XDSL file.\n', bnetNames{i} );
        bnet = org.mensxmachina.pgm.xdslread(bnetds.fileName{i}, 'nominal');
        
    end

    bnet.VarNames
    
    save(bnetFile, 'bnet');
    
end

end

