function net = grass
%GRASS Create the grass example Categorical Bayesian Network

%   Copyright 2010-2011 Mens X Machina
%
%   This file is part of Mens X Machina Probabilistic Graphical Model
%   Toolbox.
%
%   Mens X Machina Probabilistic Graphical Model Toolbox is free software:
%   you can redistribute it and/or modify it under the terms of the GNU 
%   General Public License as published by the Free Software Foundation,
%   either version 3 of the License, or (at your option) any later version.
%
%   Mens X Machina Probabilistic Graphical Model Toolbox is distributed in
%   the hope that it will be useful, but WITHOUT ANY WARRANTY; without even
%   the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
%   PURPOSE. See the GNU General Public License for more details.
%
%   You should have received a copy of the GNU General Public License along
%   with Mens X Machina Probabilistic Graphical Model Toolbox. If not, see
%   <http://www.gnu.org/licenses/>.

node = struct('Cloudy', 1, ...
              'Sprinkler', 2, ...
              'Rain', 3, ...
              'WetGrass', 4);

G = sparse(4, 4);
G([node.Cloudy], node.Sprinkler) = 1;
G([node.Cloudy], node.Rain) = 1;
G([node.Rain node.Sprinkler], node.WetGrass) = 1;

numLevels = [2 2 2 2];

Param{node.Cloudy} = [0.5; 0.5];
Param{node.Sprinkler} = reshape([0.5 0.5 0.9 0.1], [2 2]);
Param{node.Rain} = reshape([0.8 0.2 0.2 0.8], [2 2]);
Param{node.WetGrass} = reshape([1.0 0.0 0.9 0.1  0.1 0.9 0.01 0.99], [2 2 2]);


VarNames = fieldnames(node)';

Labels = {{'false', 'true'}, ...
         {'false', 'true'}, ...
         {'false', 'true'}, ...
         {'false', 'true'}};

description = ['Example from Russell and Norvig, "Artificial' ...
               'Intelligence: a Modern Approach", Prentice Hall, ' ...
               '1995, page 454.'];

net = org.mensxmachina.pgm.CategoricalBayesianNetwork(G, numLevels, Param, 'VarNames', VarNames, 'Labels', Labels, 'Description', description);

end
