function [tpr fpr threshold] = plotpcroc(targetskeleton, p, t)
%PLOTPCROC Plot parents and children learning ROC
%
%   PLOTPCROC is called just like ORG.MENSXMACHINA.PGM.PCROC, but it also
%   plots the Receiver Operating Characteristic.
%
%   Example:
%
%       % load ALARM network
%       load mxm_bnet_alarm_net; % loads 'net' BayesianNetwork
%
%       % load ALARM network samples
%       load mxm_bnet_alarm_sample; % loads 'a' dataset
%
%       % learn parents and children set of variable #37
%       [pc p stat] = ...
%           org.mensxmachina.pgm.mmpc(a, 37, 'includeNpc', true);
%
%       % get true skeleton
%       skeleton_true = net.skeleton;
%
%       % plot ROC for variable #37
%       [tpr fpr threshold] = ..
%           org.mensxmachina.pgm.plotpcroc(skeleton_true, p, 37);
%
%   See also: 
%       ORG.MENSXMACHINA.COMMONS.STATS.ROC, ORG.MENSXMACHINA.PGM.PCROC,
%       ORG.MENSXMACHINA.PGM.PCAUC 

%   Copyright 2010-2011 Mens X Machina
%
%   This file is part of Mens X Machina Probabilistic Graphical Model
%   Toolbox.
%
%   Mens X Machina Probabilistic Graphical Model Toolbox is free software:
%   you can redistribute it and/or modify it under the terms of the GNU 
%   General Public License as published by the Free Software Foundation,
%   either version 3 of the License, or (at your option) any later version.
%
%   Mens X Machina Probabilistic Graphical Model Toolbox is distributed in
%   the hope that it will be useful, but WITHOUT ANY WARRANTY; without even
%   the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
%   PURPOSE. See the GNU General Public License for more details.
%
%   You should have received a copy of the GNU General Public License along
%   with Mens X Machina Probabilistic Graphical Model Toolbox. If not, see
%   <http://www.gnu.org/licenses/>.

% get roc inputs
[targets outputs] = rocinputs(targetskeleton, p, t);
    
% plot ROC
[tpr fpr threshold] = ...
    org.mensxmachina.commons.stats.plotroc(targets, outputs);

end

function [targets outputs] = rocinputs(targetskeleton, p, t)

targets = targetskeleton(t, :);
targets(t) = []; % remove target variable

outputs = -p;
outputs(t) = []; % remove target variable

end