function [tpr fpr threshold] = plotskeletonroc(targetskeleton, p)
%PLOTSKELETONROC Plot skeleton learner receiver operating characteristic
%
%   PLOTSKELETONROC is called just like ORG.MENSXMACHINA.PGM.SKELETONROC,
%   but it also plots the Receiver Operating Characteristic.
%
%   Example:
%
%       % load ALARM network samples
%       load mxm_bnet_alarm_sample; % loads 'a' dataset
%
%       % learn skeleton
%       [skeleton p stat] = ...
%           org.mensxmachina.pgm.mmpcskeleton(a, 'includeNonSkeletonStats', true);
%
%       % load ALARM network
%       load mxm_bnet_alarm_net; % loads 'net' network
%
%       % get true skeleton
%       skeleton_true = net.skeleton;
%
%       % plot ROC
%       [tpr fpr threshold] = ...
%           org.mensxmachina.pgm.plotskeletonroc(skeleton_true, p)
%
%   See also: 
%       ORG.MENSXMACHINA.PGM.SKELETONROC,
%       ORG.MENSXMACHINA.PGM.SKELETONAUC,
%       ORG.MENSXMACHINA.COMMONS.STATS.PLOTROC

%   Copyright 2010-2011 Mens X Machina
%
%   This file is part of Mens X Machina Probabilistic Graphical Model
%   Toolbox.
%
%   Mens X Machina Probabilistic Graphical Model Toolbox is free software:
%   you can redistribute it and/or modify it under the terms of the GNU 
%   General Public License as published by the Free Software Foundation,
%   either version 3 of the License, or (at your option) any later version.
%
%   Mens X Machina Probabilistic Graphical Model Toolbox is distributed in
%   the hope that it will be useful, but WITHOUT ANY WARRANTY; without even
%   the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
%   PURPOSE. See the GNU General Public License for more details.
%
%   You should have received a copy of the GNU General Public License along
%   with Mens X Machina Probabilistic Graphical Model Toolbox. If not, see
%   <http://www.gnu.org/licenses/>.

% convert skeleton to vector
targets = org.mensxmachina.commons.graph.skeleton2vector(targetskeleton);

% convert maximum p-value matrix to vector
outputs = -org.mensxmachina.commons.graph.skeleton2vector(p);

[tpr fpr threshold] = org.mensxmachina.commons.stats.plotroc(targets, outputs);

end