function [skeleton p stat flag Stats] = gllpcopt(x, numLevels, ord, j, InstParam, Param)
%GLLPCOPT GLL-PC

%   References:
%       [1] Aliferis, C. F., Statnikov, A., Tsamardinos, I., Mani, S., and
%       Koutsoukos, X. D. 2010. Local Causal and Markov Blanket Induction 
%       for Causal Discovery and Feature Selection for Classification Part
%       I: Algorithms and Empirical Evaluation. J. Mach. Learn. Res. 11
%       (Mar. 2010), 171-234.

%   Copyright 2010-2011 Mens X Machina
%
%   This file is part of Mens X Machina Probabilistic Graphical Model
%   Toolbox.
%
%   Mens X Machina Probabilistic Graphical Model Toolbox is free software:
%   you can redistribute it and/or modify it under the terms of the GNU 
%   General Public License as published by the Free Software Foundation,
%   either version 3 of the License, or (at your option) any later version.
%
%   Mens X Machina Probabilistic Graphical Model Toolbox is distributed in
%   the hope that it will be useful, but WITHOUT ANY WARRANTY; without even
%   the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
%   PURPOSE. See the GNU General Public License for more details.
%
%   You should have received a copy of the GNU General Public License along
%   with Mens X Machina Probabilistic Graphical Model Toolbox. If not, see
%   <http://www.gnu.org/licenses/>.

% params: GllPcNonSymFun, GllPcNonSymParam, GllPcStatsFun, GllPcStatsParam

% initiliaze GLL output
[skeleton p stat flag Stats] = glloutputinit(x, numLevels, ord, Param);
 
% learn TPC(J)
fprintf('\nLearning TPC(%d)...\n', j);

% call GLL-PC-nonsym for J

if flag(j)
    return;
else
    [skeleton p stat flag Stats] = ...
        gllpcnonsymopt(x, numLevels, ord, j, skeleton, p, stat, flag, Stats, InstParam, Param);
end

for j2 = find(skeleton(j, :)) % for each variable J2 in TPC(J)
    
    % learn TPC(J2)
    fprintf('\nLearning TPC(%d)...\n', j2);

    % call GLL-PC-nonsym
    if ~flag(j2)
        [skeleton p stat flag Stats] = ...
            gllpcnonsymopt(x, numLevels, ord, j2, skeleton, p, stat, flag, Stats, InstParam, Param);
    end
    
end

end