function [skeleton p stat tpc Stats] = mmpctpcrmopt(x, numLevels, ord, j, skeleton, p, stat, flag, tpc, open, Stats, ~, Param)
%MMPCTPCRMOPT Remove from MMPC TPC

%   Copyright 2010-2011 Mens X Machina
%
%   This file is part of Mens X Machina Probabilistic Graphical Model
%   Toolbox.
%
%   Mens X Machina Probabilistic Graphical Model Toolbox is free software:
%   you can redistribute it and/or modify it under the terms of the GNU 
%   General Public License as published by the Free Software Foundation,
%   either version 3 of the License, or (at your option) any later version.
%
%   Mens X Machina Probabilistic Graphical Model Toolbox is distributed in
%   the hope that it will be useful, but WITHOUT ANY WARRANTY; without even
%   the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
%   PURPOSE. See the GNU General Public License for more details.
%
%   You should have received a copy of the GNU General Public License along
%   with Mens X Machina Probabilistic Graphical Model Toolbox. If not, see
%   <http://www.gnu.org/licenses/>.

%PHASE2 Phase II (backward): remove variables from TPC(J)

if ~isempty(open)
    
    % OPEN not empty yet...
    return;
    
end

%{
% RL 3 dumped
if Param.Rl == 3 % MTPCs are reused
    
    % cache current (maximal) TPC(j) as the MTPC(J)
    Cache.isMtpc{j} = sparse(1, tpc, true, 1, m);
    Cache.mtpcOrder{j} = sparse(1, tpc, 1:numel(tpc), 1, m);

end
%}

if numel(tpc) < 2
    
    % if 0, nothing to remove
    % if 1, there are no other variables in TPC(J) that could be affected
    % by the insertion of the last and only variable F
    return;
    
end

for j2IndInTpc_j = 1:numel(tpc)-1 % for each variable in TPC(J) except the last one (F)
    
    % let it be J2
    j2 = tpc(j2IndInTpc_j);
    
    % we exclude F, the last variable added to TPC(J),
    % because it is already known that F is associated with J
    % given any subset of the previous TPC(J)
    
    % find indices of the rest variables in TPC(J) not yet removed;
    % in the extreme case this in only the last variable (F)
    %indices = setdiff( [ 1 : (j2IndInTpc_j - 1) (j2IndInTpc_j + 1) : numel(tpc)], find(tpc(~skeleton(j, tpc))) );
    indices = setdiff( [ 1 : (j2IndInTpc_j - 1) (j2IndInTpc_j + 1) : numel(tpc)], find(~skeleton(j, tpc)) ); % bug fixed
    
    % find the maximal conditioning set cardinality with sufficient power
    powerMaxK = Param.PowerMaxKFun(x, numLevels, ord, j2, j, indices, Param.Alpha, Param.Beta, Param.TestParam, Param.PowerParam);

    % get minimum between sufficient power maxk and user MAXK
    maxK = min(powerMaxK, Param.MaxK);
    
    if maxK == 0
        continue;
    end
    
    if numel(indices) == 1
        
        % extreme case: only I(J2;J|F) is left to be tested
        
        % test I(J2;J|F)
        f = tpc(end);
        
        [skeleton p stat Stats] = gllskeletonupdateopt(x, numLevels, ord, j2, j, f, skeleton, p, stat, flag, Stats, Param);
        
        break; % finished
        
    end
    
    for nj3 = 1:maxK % for each cardinality to the maximum
        
        % note: for J2 in TPC(J), I(J2;J|[]) has been tested; 
        % ignoring size 0
        
        % find subsets of -indices- of variables in TPC(J) 
        % of this size that do not contain the index of J2      
        C = nchoosek(indices, nj3);
        
        for k = 1:size(C, 1) % for each such index subset
            
            if max(C(k, :)) < j2IndInTpc_j
                
                % subset is older in TPC(J) than J2, test already performed
                continue;
                
            end
            
            % let it be J3
            j3 = tpc(C(k, :));

            % test I(J2;J|J3)
            [skeleton p stat Stats] = gllskeletonupdateopt(x, numLevels, ord, j2, j, j3, skeleton, p, stat, flag, Stats, Param);                

            if ~skeleton(j, j2)
                break;
            end
            
        end

        if ~skeleton(j, j2)
            break;
        end

    end

end

% eliminate variables with no association with J given TPC(J) from TPC(J)
tpc(~skeleton(j, tpc)) = [];

end