function [p_vector rlzdMsr_vector] = multskeletondata2vectorinput(skeleton, p, rlzdMsr, functionName)
%MULTSKELETONDATA2VECTORINPUT Summary of this function goes here
%   Detailed explanation goes here

import org.mensxmachina.commons.graph.*;

ip = inputParser; % Create an instance of the inputParser class
ip.FunctionName = upper(functionName);

ip.addRequired('skeleton', @(skeleton) iscell(skeleton) && all(cellfun(@(iSkeleton) issparse(iSkeleton) && issquarematrix(iSkeleton), skeleton)));
ip.addRequired('p', @(skeleton) iscell(p) && all(cellfun(@(iP) isnumeric(iP) && issquarematrix(iP), p)));
ip.addRequired('rlzdMsr', @(rlzdMsr) iscell(rlzdMsr) && all(all(cellfun(@(ijRlzdMsr) isnumeric(ijRlzdMsr) && issquarematrix(ijRlzdMsr), rlzdMsr))));

ip.parse(skeleton, p, rlzdMsr);
    
assert(length(p) == length(skeleton), ...
   [lower(functionName) 'PLengthNotSkeletonLength'], ...
   'P must be of the same length as SKELETON.'); 

assert(size(rlzdMsr, 1) == length(p) || size(rlzdMsr, 2) == length(p), ...
   [lower(functionName) 'PMeasureDimensionMismatch'], ...
   'The dimensions of P and MEASURE do not match.');

if size(rlzdMsr, 1) ~= size(rlzdMsr, 2) && size(rlzdMsr, 2) == length(p)
    rlzdMsr = rlzdMsr'; % transpose so that rlzdMsr correspond to columns
end

assert( all(arrayfun(@(i) all(cellfun(@(ijRlzdMsr) isequal(size(ijRlzdMsr), size(p{i})), rlzdMsr(i, :))), 1:length(p))), ...
   [lower(functionName) 'PMeasureElementsDimensionMismatch'], ...
   'The dimensions of the elements of P and MEASURE do not match.'); 

% convert skeleton matrices to vectors
skeleton_vector = cellfun(@skeleton2vector, skeleton, 'UniformOutput', false);

% convert p-value matrix to vector
p_vector = cellfun(@skeleton2vector, p, 'UniformOutput', false);

% convert realized measure matrices to vectors
rlzdMsr_vector = cellfun(@skeleton2vector, rlzdMsr, 'UniformOutput', false);

for i=1:length(skeleton_vector) % for each skeleton

    if issparse(p{i})

        % get edge linear indices in skeleton vector
        skeleton_vector_ind = find(skeleton_vector{i});

        % keep only maximum p-values corresponding to edges and convert to full
        p_vector{i} = full(p_vector{i}(skeleton_vector_ind));

        for j=1:size(rlzdMsr_vector, 2) % for each rlzdMsr
        
            % keep only rlzdMsr values corresponding to edges and convert to full
            rlzdMsr_vector{i, j} = full(rlzdMsr_vector{i, j}(skeleton_vector_ind));
        
        end

    end

end

end

