classdef TestSkeletonFdr < TestCase
%TESTROC roc test cases

properties
    
end

methods

function obj = TestSkeletonFdr(name)

obj = obj@TestCase(name);

end

function testtoydata(obj)
   
import org.mensxmachina.commons.stats.*;
import org.mensxmachina.pgm.*;

skeleton = [ ...
        0 0 1 0 ;
        0 0 1 1 ;
        1 1 0 1 ;
        0 1 1 0 ;
    ];
     
skeleton = sparse(skeleton);

p = [ ...
        0       0       0.01	0 ;
        0       0       0.03	0.02 ;
        0.01    0.03   	0       0.04 ;
        0       0.02	0.04       0 ;
    ];

p = sparse(p);

m = 4*(4-1)/2;

% p_sorted = [0.01 0.02 0.03 0.04]

fdr_true = [ ...
        0       0           0.01*m       0 ;
        0       0           0.03*m/3     0.02*m/2 ;
        0.01*m  0.03*m/3   	0            0.04*m/4 ;
        0       0.02*m/2   	0.04*m/4     0 ;
    ];

fdr_true = sparse(fdr_true);

% FDR

% compute it
fdr = skeletonfdr(skeleton, p, 'PFdr', false);

assertEqual(fdr, fdr_true);

% test thresholds
   
% convert skeleton matrix to vector
skeleton_vector = org.mensxmachina.commons.graph.skeleton2vector(skeleton);

% convert maximum p-value matrix to vector
p_vector = org.mensxmachina.commons.graph.skeleton2vector(p);
fdr_vector = org.mensxmachina.commons.graph.skeleton2vector(fdr);

% get edge linear indices in skeleton vector
skeleton_vector_ind = find(skeleton_vector);

% keep only maximum p-values corresponding to edges and convert to full
p_skeleton_vector = full(p_vector(skeleton_vector_ind));
fdr_skeleton_vector = full(fdr_vector(skeleton_vector_ind));

t_order = randperm(length(p_skeleton_vector));
t = p_skeleton_vector(t_order);
fdr_t = skeletonfdr(skeleton, p, 'PFdr', false, 'Thresholds', t);
assertEqual(fdr_t, fdr_skeleton_vector(t_order));

end
%{
function testthresholds(obj)
    
import org.mensxmachina.commons.stats.*;
import org.mensxmachina.pgm.*;
    
a = [];
load('mxm_pgm_andes_sample', 'a'); % load sample
%a = a(1:100, :); % keep only x first samples

% learn skeleton
[skeleton p] = mmpcskeleton(a);

fdr = skeletonfdr(skeleton, p, 'pFDR', false);

t = logspace(-4, -1)';

fdr_t = skeletonfdr(skeleton, p, 'pFDR', false, 'Thresholds', t);
fdr_max_p_lte_t = skeletonfprthresholdrlzdmsrstats({skeleton}, {p}, {fdr}, t);

semilogx(t, [fdr_t fdr_max_p_lte_t]);
legend('FDR(t)', 'FDR(max{p: p <= t})');

end


function testcmp(obj)
% test by comparing to realized FDR   
    
import org.mensxmachina.commons.stats.*;
import org.mensxmachina.pgm.*;
    
load('mxm_pgm_alarm_bnet', 'bnet'); % load bnet
skeleton_true = bnet.skeleton; % get true skeleton
clear bnet;

alpha = 0.05;

a = [];
load('mxm_pgm_alarm_sample', 'a'); % load sample
%a = a(1:100, :); % keep only x first samples

% learn skeleton
[skeleton p] = mmpcskeleton(a);

% Realized FDR
realizedFdr = skeletonrlzdfdr(skeleton, p, skeleton_true);

% BH FDR
fdr = skeletonfdr(skeleton, p);

% MC pFDR

b = 10;

randomTargetSkeleton = cell(1, b);
randomOutputSkeleton = cell(1, b);
randomP = cell(1, b);

for i=1:b % for each iteration
    
    randomBNetName = sprintf('alarm_random_%d', i);

    % load random skeleton
    load(sprintf('mxm_pgm_%s_bnet', randomBNetName), 'bnet');

    randomTargetSkeleton{i} = bnet.skeleton;
    clear bnet;

    % load sample
    load(sprintf('mxm_pgm_%s_sample', randomBNetName), 'a'); 
    %a = a(1:100, :); % keep only x first samples
    
    % learn skeleton
    [randomOutputSkeleton{i} randomP{i}] = mmpcskeleton(a);
    
    cp = skeletonperf(randomTargetSkeleton{i}, randomOutputSkeleton{i});
    
    cp.Sensitivity
    cp.Specificity
    
end

mcpFdr = skeletonfdr(skeleton, p, 'RandomOutputSkeleton', randomOutputSkeleton, 'RandomP', randomP, 'RandomTargetSkeleton', randomTargetSkeleton);

h = zeros(1, 3);
close all;
h(1) = skeletonfprthresholdmsrplot({skeleton}, {p}, {realizedFdr}, alpha/100:alpha/100:alpha, 'RealizedMeasureDefault', 0, 'ErrorStat', 'std', 'Color', 'b');
hold all;
h(2) = skeletonfprthresholdmsrplot({skeleton}, {p}, {fdr}, alpha/100:alpha/100:alpha, 'RealizedMeasureDefault', 0, 'ErrorStat', 'std', 'Color', 'r');
hold all;
h(3) = skeletonfprthresholdmsrplot({skeleton}, {p}, {mcpFdr}, alpha/100:alpha/100:alpha, 'RealizedMeasureDefault', NaN, 'ErrorStat', 'std', 'Color', 'g');
legend(h, {'Realized FDR', 'BH FDR', 'MC pFDR'});
xlabel('p-value');
ylabel('value');
ylim([0 1]);
hold off;

end
%}
end

end
