classdef TestSkeletonRlzdFdr < TestCase
%TESTSKELETONRLZDFDR SKELETONRLZDFDR test cases

properties
    TrueSkeleton
    Skeleton
    P
    TrueRealizedFdr
end

methods

function obj = TestSkeletonRlzdFdr(name)

obj = obj@TestCase(name);

obj.TrueSkeleton = [ ...
        0 1 1 0 ;
        1 0 0 1 ;
        1 0 0 1 ;
        0 1 1 0 ;
    ];
     
obj.TrueSkeleton = sparse(obj.TrueSkeleton);

obj.Skeleton = [ ...
        0 0 1 0 ;
        0 0 1 1 ;
        1 1 0 1 ;
        0 1 1 0 ;
    ];
     
obj.Skeleton = sparse(obj.Skeleton);

obj.P = [ ...
           1    0.06    0.01	0.06 ;
        0.06       1    0.03	0.02 ;
        0.01    0.03   	   1    0.04 ;
        0.06    0.02	0.04       1 ;
    ];

obj.TrueRealizedFdr = [ ...
        1       2/6     0     2/6 ;
        2/6     1       1/3     0 ;
          0     1/3     1       1/4 ;
        2/6     0       1/4     1 ;
    ];

obj.TrueRealizedFdr = obj.TrueRealizedFdr;

end

function testtoy(obj)
   
import org.mensxmachina.commons.graph.*;    
import org.mensxmachina.commons.stats.*;
import org.mensxmachina.pgm.*;

nonSkeletonInd = find(~obj.Skeleton);

p = obj.P;
p(nonSkeletonInd) = 0;
p = sparse(p);

trueRealizedFdr = obj.TrueRealizedFdr;
trueRealizedFdr(nonSkeletonInd) = 0;
trueRealizedFdr = sparse(trueRealizedFdr);

realizedFdr = skeletonrlzdfdr(obj.Skeleton, p, obj.TrueSkeleton);

assertEqual(realizedFdr, trueRealizedFdr);

% test thresholds
   
% convert skeleton matrix to vector
skeleton_vector = org.mensxmachina.commons.graph.skeleton2vector(obj.Skeleton);

% convert maximum p-value matrix to vector
p_vector = org.mensxmachina.commons.graph.skeleton2vector(p);
realizedFdr_vector = org.mensxmachina.commons.graph.skeleton2vector(realizedFdr);

% get edge linear indices in skeleton vector
skeleton_vector_ind = find(skeleton_vector);

% keep only maximum p-values corresponding to edges and convert to full
p_skeleton_vector = full(p_vector(skeleton_vector_ind));
realizedFdr_skeleton_vector = full(realizedFdr_vector(skeleton_vector_ind));

t_order = randperm(length(p_skeleton_vector));
t = p_skeleton_vector(t_order);
realizedFdr_t = skeletonrlzdfdr(obj.Skeleton, p, obj.TrueSkeleton, t);
assertEqual(realizedFdr_t, realizedFdr_skeleton_vector(t_order));

end

function testempty(obj)
   
import org.mensxmachina.pgm.*;    
    
realizedFdr = skeletonrlzdfdr(sparse(4, 4), sparse(4, 4), obj.TrueSkeleton);

assertEqual(realizedFdr, sparse(4, 4));
    
end

end

end